@@ -2,7 +2,7 @@ package Class::DBI::SQLite;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = "0.08";
+$VERSION = "0.09";
 
 require Class::DBI;
 use base qw(Class::DBI);
@@ -32,19 +32,21 @@ SQL
     my($sql) = $sth->fetchrow_array;
     $sth->finish;
     my ($primary) = $sql =~ m/
-    (?:\(|\,) # either a ( to start the definition or a , for next 
-    \s* # maybe some whitespace
-    (\w+) # the col name
-    [^,]* #anything but the end or a ',' for next column
+    (?:\(|\,) # either a ( to start the definition or a , for next
+    \s*       # maybe some whitespace
+    (\w+)     # the col name
+    [^,]*     # anything but the end or a ',' for next column
     PRIMARY\sKEY/sxi;
-    my @mpks;
-    unless ($primary) { 
-        my ($mpks)= $sql =~ m/PRIMARY\s+KEY\s*\(\s*(.+)\s*\)/;
-        @mpks = split m/\s*\,\s*/,$mpks;
+    my @pks;
+    if ($primary) {
+        @pks = ($primary);
+    } else {
+        my ($pks)= $sql =~ m/PRIMARY\s+KEY\s*\(\s*([^)]+)\s*\)/;
+        @pks = split m/\s*\,\s*/, $pks;
     }
     $class->table($table);
+    $class->columns(Primary => @pks);
     $class->columns(All => @columns);
-    $class->columns(Primary => $primary || @mpks);
 }
 
 1;
@@ -71,11 +73,11 @@ Class::DBI::SQLite - Extension to Class::DBI for sqlite
 
 =head1 DESCRIPTION
 
-Class::DBI::SQLite is an extension to Class::DBI for DBD::SQLite,
-which allows you to populate auto incremented row id after insert.
+Class::DBI::SQLite is an extension to Class::DBI for DBD::SQLite.
+It allows you to populate an auto-incremented row id after insert.
 
-C<set_up_table> method allows you to automate the setup of columns and
-primary key by using of SQLite PRAGMA statement 
+The C<set_up_table> method automates the setup of columns and
+primary key(s) via the SQLite PRAGMA statement.
 
 =head1 AUTHOR
 
